@@ -2,10 +2,16 @@ import argparse
 import os
 import sys
 from enum import Enum
+from typing import List, Optional
+
+from strictdoc.backend.reqif.sdoc_reqif_fields import ReqIFProfile
+from strictdoc.cli.argument_int_range import IntRange
+from strictdoc.core.environment import SDocRuntimeEnvironment
+from strictdoc.core.project_config import ProjectConfig, ProjectFeature
+from strictdoc.helpers.auto_described import auto_described
 
 EXPORT_FORMATS = ["html", "html-standalone", "rst", "excel", "reqif-sdoc"]
-
-REQIF_PARSERS = ["sdoc"]
+EXCEL_PARSERS = ["basic"]
 
 
 def _check_formats(formats):
@@ -24,34 +30,51 @@ def _parse_fields(fields):
     return fields_array
 
 
-def cli_args_parser() -> argparse.ArgumentParser:
-    # for arg in sys.argv:
-    #     if arg == '--help':
-    #         # print_help()
-    #         assert 0
-    #         exit(0)
-    #
-    # for arg in sys.argv:
-    #     if arg == '--version':
-    #         # print_version()
-    #         assert 0
-    #         exit(0)
+class SDocArgumentParser(argparse.ArgumentParser):
+    def error(self, message: str):
+        self.print_usage(sys.stderr)
+        print(f"{self.prog}: error: {message}", file=sys.stderr)  # noqa: T201
+        print("")  # noqa: T201
+        print("Further help:")  # noqa: T201
+        print(  # noqa: T201
+            "'strictdoc -h/--help' provides a general overview of available commands."  # noqa: E501
+        )
+        print(  # noqa: T201
+            "'strictdoc <command> -h/--help' provides command-specific help."
+        )
+        sys.exit(2)
 
+
+def cli_args_parser() -> argparse.ArgumentParser:
     def formatter(prog):
         return argparse.RawTextHelpFormatter(
             prog, indent_increment=2, max_help_position=4, width=80
         )
 
     # https://stackoverflow.com/a/19476216/598057
-    main_parser = argparse.ArgumentParser()
-    main_parser.formatter_class = formatter
-
+    main_parser = SDocArgumentParser(
+        prog="strictdoc",
+        add_help=True,
+        epilog=(
+            """
+            Further help: https://strictdoc.readthedocs.io/en/stable/
+            """
+        ),
+    )
     command_subparsers = main_parser.add_subparsers(
         title="command", dest="command"
     )
     command_subparsers.required = True
 
-    # Command: Export
+    # Command – About
+    _ = command_subparsers.add_parser(
+        "about",
+        help="About StrictDoc.",
+        description="About StrictDoc.",
+        formatter_class=formatter,
+    )
+
+    # Command – Export
     command_parser_export = command_subparsers.add_parser(
         "export",
         help="Export document tree.",
@@ -108,7 +131,7 @@ def cli_args_parser() -> argparse.ArgumentParser:
         ),
     )
 
-    # Command: Import
+    # Command – Import
     command_parser_import = command_subparsers.add_parser(
         "import",
         help="Create StrictDoc files from other formats.",
@@ -129,19 +152,19 @@ def cli_args_parser() -> argparse.ArgumentParser:
     )
 
     def check_reqif_parser(parser):
-        if parser not in REQIF_PARSERS:
+        if parser not in ReqIFProfile.ALL:
             message = (
-                f"invalid choice: '{parser}' (choose from {REQIF_PARSERS})"
+                f"invalid choice: '{parser}' (choose from {ReqIFProfile.ALL})"
             )
             raise argparse.ArgumentTypeError(message)
         return parser
 
     command_parser_import_reqif.add_argument(
-        "parser",
+        "profile",
         type=check_reqif_parser,
         help=(
-            "An argument that selects the ReqIF parser. "
-            f"Possible values: {{{', '.join(REQIF_PARSERS)}}}"
+            "An argument that selects the ReqIF import/export profile. "
+            f"Possible values: {{{', '.join(ReqIFProfile.ALL)}}}"
         ),
     )
     command_parser_import_reqif.add_argument(
@@ -164,10 +187,9 @@ def cli_args_parser() -> argparse.ArgumentParser:
     )
 
     def check_excel_parser(parser):
-        excel_parsers = ["basic"]
-        if parser not in excel_parsers:
+        if parser not in EXCEL_PARSERS:
             message = (
-                f"invalid choice: '{parser}' (choose from {excel_parsers})"
+                f"invalid choice: '{parser}' (choose from {EXCEL_PARSERS})"
             )
             raise argparse.ArgumentTypeError(message)
         return parser
@@ -177,7 +199,7 @@ def cli_args_parser() -> argparse.ArgumentParser:
         type=check_excel_parser,
         help=(
             "An argument that selects the ReqIF parser. "
-            f"Possible values: {{{', '.join(REQIF_PARSERS)}}}"
+            f"Possible values: {{{', '.join(EXCEL_PARSERS)}}}"
         ),
     )
     command_parser_import_excel.add_argument(
@@ -191,7 +213,7 @@ def cli_args_parser() -> argparse.ArgumentParser:
         help="Path to the output SDoc file.",
     )
 
-    # Command: Passthrough
+    # Command – Passthrough
     command_parser_passthrough = command_subparsers.add_parser(
         "passthrough",
         help="Read an SDoc file, then output it again. (used for testing)",
@@ -205,7 +227,7 @@ def cli_args_parser() -> argparse.ArgumentParser:
         "--output-file", type=str, help="Path to the output SDoc file"
     )
 
-    # Command: Dump Grammar
+    # Command – Dump Grammar
     command_parser_dump_grammar = command_subparsers.add_parser(
         "dump-grammar",
         help="Dump the SDoc grammar to a .tx file.",
@@ -215,7 +237,26 @@ def cli_args_parser() -> argparse.ArgumentParser:
         "output_file", type=str, help="Path to the output .tx file"
     )
 
-    # Command: Version
+    # Command – Server
+    command_parser_server = command_subparsers.add_parser(
+        "server",
+        help="Run StrictDoc Web server.",
+        description="Run StrictDoc Web server.",
+        formatter_class=formatter,
+    )
+    command_parser_server.add_argument("input_path")
+    command_parser_server.add_argument("--output-path", type=str)
+    command_parser_server.add_argument(
+        "--reload", default=False, action="store_true"
+    )
+    command_parser_server.add_argument(
+        "--no-reload", dest="reload", action="store_false"
+    )
+    command_parser_server.add_argument(
+        "--port", default=5111, type=IntRange(1000, 65000)
+    )
+
+    # Command – Version
     command_subparsers.add_parser(
         "version",
         help="Print the version of StrictDoc.",
@@ -225,10 +266,10 @@ def cli_args_parser() -> argparse.ArgumentParser:
 
 
 class ImportReqIFCommandConfig:
-    def __init__(self, input_path, output_path, parser):
-        self.input_path = input_path
-        self.output_path = output_path
-        self.parser = parser
+    def __init__(self, input_path: str, output_path: str, profile):
+        self.input_path: str = input_path
+        self.output_path: str = output_path
+        self.profile: Optional[str] = profile
 
 
 class ImportExcelCommandConfig:
@@ -244,6 +285,27 @@ class PassthroughCommandConfig:
         self.output_file = output_file
 
 
+@auto_described
+class ServerCommandConfig:
+    def __init__(
+        self,
+        *,
+        environment: SDocRuntimeEnvironment,
+        input_path: str,
+        output_path: Optional[str],
+        reload: bool,
+        port: int,
+    ):
+        assert os.path.exists(input_path)
+        assert isinstance(port, int)
+        self.environment: SDocRuntimeEnvironment = environment
+        abs_input_path = os.path.abspath(input_path)
+        self.input_path: str = abs_input_path
+        self.output_path: Optional[str] = output_path
+        self.reload: bool = reload
+        self.port = port
+
+
 class ExportMode(Enum):
     DOCTREE = 1
     STANDALONE = 2
@@ -253,20 +315,21 @@ class ExportMode(Enum):
 class ExportCommandConfig:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        strictdoc_root_path,
+        environment: SDocRuntimeEnvironment,
         input_paths,
         output_dir: str,
-        project_title,
+        project_title: Optional[str],
         formats,
         fields,
         no_parallelization,
         enable_mathjax,
         experimental_enable_file_traceability,
     ):
-        self.strictdoc_root_path = strictdoc_root_path
-        self.input_paths = input_paths
+        assert isinstance(input_paths, list), f"{input_paths}"
+        self.environment: SDocRuntimeEnvironment = environment
+        self.input_paths: List[str] = input_paths
         self.output_dir: str = output_dir
-        self.project_title = project_title
+        self.project_title: Optional[str] = project_title
         self.formats = formats
         self.fields = fields
         self.no_parallelization = no_parallelization
@@ -276,6 +339,25 @@ class ExportCommandConfig:  # pylint: disable=too-many-instance-attributes
         )
         self.output_html_root: str = os.path.join(output_dir, "html")
 
+        self.is_running_on_server = False
+
+        # This option comes from the project config when the
+        # config file is read.
+        self.dir_for_sdoc_assets: str = ""
+
+        # FIXME: This does not belong here.
+        self._server_port: Optional[int] = None
+
+    def configure_for_server(self, server_port: int):
+        assert isinstance(server_port, int)
+        self.is_running_on_server = True
+        self._server_port = server_port
+
+    @property
+    def server_port(self) -> int:
+        assert self._server_port is not None
+        return self._server_port
+
     def get_export_mode(self):
         if "html" in self.formats:
             if "html-standalone" in self.formats:
@@ -285,26 +367,25 @@ class ExportCommandConfig:  # pylint: disable=too-many-instance-attributes
             return ExportMode.STANDALONE
         raise NotImplementedError
 
+    @property
+    def strictdoc_root_path(self):
+        return self.environment.path_to_strictdoc
+
     def get_static_files_path(self):
-        if getattr(sys, "frozen", False):
-            # If the application is run as a bundle, the PyInstaller bootloader
-            # extends the sys module by a flag frozen=True and sets the app
-            # path into variable _MEIPASS'.
-            bundle_dir = sys._MEIPASS  # pylint: disable=protected-access
-            return os.path.join(bundle_dir, "_static")
-        return os.path.join(
-            self.strictdoc_root_path, "strictdoc/export/html/_static"
-        )
+        return self.environment.get_static_files_path()
 
     def get_extra_static_files_path(self):
-        if getattr(sys, "frozen", False):
-            # If the application is run as a bundle, the PyInstaller bootloader
-            # extends the sys module by a flag frozen=True and sets the app
-            # path into variable _MEIPASS'.
-            bundle_dir = sys._MEIPASS  # pylint: disable=protected-access
-            return os.path.join(bundle_dir, "_static_extra")
-        return os.path.join(
-            self.strictdoc_root_path, "strictdoc/export/html/_static_extra"
+        return self.environment.get_extra_static_files_path()
+
+    def integrate_project_config(self, project_config: ProjectConfig):
+        if self.project_title is None:
+            self.project_title = project_config.project_title
+        self.dir_for_sdoc_assets = project_config.dir_for_sdoc_assets
+        self.experimental_enable_file_traceability = (
+            self.experimental_enable_file_traceability
+            or project_config.is_feature_activated(
+                ProjectFeature.REQUIREMENT_TO_SOURCE_TRACEABILITY
+            )
         )
 
 
@@ -317,6 +398,10 @@ class SDocArgsParser:
     def __init__(self, args):
         self.args = args
 
+    @property
+    def is_about_command(self):
+        return self.args.command == "about"
+
     @property
     def is_passthrough_command(self):
         return self.args.command == "passthrough"
@@ -337,6 +422,10 @@ class SDocArgsParser:
             self.args.command == "import" and self.args.import_format == "excel"
         )
 
+    @property
+    def is_server_command(self):
+        return self.args.command == "server"
+
     @property
     def is_dump_grammar_command(self):
         return self.args.command == "dump-grammar"
@@ -350,12 +439,11 @@ class SDocArgsParser:
             self.args.input_file, self.args.output_file
         )
 
-    def get_export_config(self, strictdoc_root_path) -> ExportCommandConfig:
-        project_title = (
-            self.args.project_title
-            if self.args.project_title
-            else "Untitled Project"
-        )
+    def get_export_config(
+        self, environment: SDocRuntimeEnvironment
+    ) -> ExportCommandConfig:
+        assert isinstance(environment, SDocRuntimeEnvironment)
+        project_title: Optional[str] = self.args.project_title
 
         output_dir = self.args.output_dir if self.args.output_dir else "output"
         if not os.path.isabs(output_dir):
@@ -363,7 +451,7 @@ class SDocArgsParser:
             output_dir = os.path.join(cwd, output_dir)
 
         return ExportCommandConfig(
-            strictdoc_root_path,
+            environment,
             self.args.input_paths,
             output_dir,
             project_title,
@@ -376,7 +464,7 @@ class SDocArgsParser:
 
     def get_import_config_reqif(self, _) -> ImportReqIFCommandConfig:
         return ImportReqIFCommandConfig(
-            self.args.input_path, self.args.output_path, self.args.parser
+            self.args.input_path, self.args.output_path, self.args.profile
         )
 
     def get_import_config_excel(self, _) -> ImportExcelCommandConfig:
@@ -384,6 +472,18 @@ class SDocArgsParser:
             self.args.input_path, self.args.output_path, self.args.parser
         )
 
+    def get_server_config(
+        self, environment: SDocRuntimeEnvironment
+    ) -> ServerCommandConfig:
+        assert isinstance(environment, SDocRuntimeEnvironment), environment
+        return ServerCommandConfig(
+            environment=environment,
+            input_path=self.args.input_path,
+            output_path=self.args.output_path,
+            reload=self.args.reload,
+            port=self.args.port,
+        )
+
     def get_dump_grammar_config(self) -> DumpGrammarCommandConfig:
         return DumpGrammarCommandConfig(output_file=self.args.output_file)
 
