@@ -17,10 +17,15 @@ class DocumentCachingIterator:
         self.nodes_cache = []
         self.toc_nodes_cache = []
 
+    def invalidate_cache(self):
+        self.nodes_cache.clear()
+        self.toc_nodes_cache.clear()
+
     def table_of_contents(self):
-        if len(self.toc_nodes_cache) > 0:
-            yield from self.toc_nodes_cache
-            return
+        # TODO: Should bring the cache back or remove?
+        # if len(self.toc_nodes_cache) > 0:  # noqa: ERA001
+        #     yield from self.toc_nodes_cache  # noqa: ERA001
+        #     return  # noqa: ERA001
 
         nodes_to_skip = (
             (FreeText, Requirement)
@@ -31,15 +36,16 @@ class DocumentCachingIterator:
         for node in self.all_content():
             if isinstance(node, nodes_to_skip):
                 continue
-            if isinstance(node, Requirement) and node.title is None:
+            if isinstance(node, Requirement) and node.reserved_title is None:
                 continue
             self.toc_nodes_cache.append(node)
             yield node
 
     def all_content(self):
-        if len(self.nodes_cache) > 0:
-            yield from self.nodes_cache
-            return
+        # TODO: Should bring the cache back or remove?
+        # if len(self.nodes_cache) > 0:  # noqa: ERA001
+        #     yield from self.nodes_cache  # noqa: ERA001
+        #     return  # noqa: ERA001
 
         document = self.document
         level_counter = LevelCounter()
@@ -57,12 +63,12 @@ class DocumentCachingIterator:
             ):
                 assert current.ng_level, f"Node has no ng_level: {current}"
 
-                if current.level != "None":
+                if current.ng_resolved_custom_level != "None":
                     level_counter.adjust(current.ng_level)
                     # TODO: Remove the need to do branching here.
                     current.context.title_number_string = (
-                        current.level
-                        if current.level
+                        current.ng_resolved_custom_level
+                        if current.ng_resolved_custom_level
                         else level_counter.get_string()
                     )
                 else:
