@@ -1,9 +1,11 @@
+from strictdoc import __version__
 from strictdoc.cli.cli_arg_parser import ExportCommandConfig
 from strictdoc.core.document_tree_iterator import DocumentTreeIterator
 from strictdoc.core.traceability_index import TraceabilityIndex
 from strictdoc.export.html.document_type import DocumentType
-from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 from strictdoc.export.html.html_templates import HTMLTemplates
+from strictdoc.export.html.renderers.link_renderer import LinkRenderer
+from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 
 
 class RequirementsCoverageHTMLGenerator:
@@ -13,7 +15,6 @@ class RequirementsCoverageHTMLGenerator:
     def export(
         config: ExportCommandConfig,
         traceability_index: TraceabilityIndex,
-        link_renderer,
     ):
         document_tree_iterator = DocumentTreeIterator(
             traceability_index.document_tree
@@ -25,6 +26,9 @@ class RequirementsCoverageHTMLGenerator:
             "requirements_coverage/requirements_coverage.jinja.html"
         )
 
+        link_renderer = LinkRenderer(
+            root_path="", static_path=config.dir_for_sdoc_assets
+        )
         markup_renderer = MarkupRenderer.create(
             "RST",
             traceability_index,
@@ -37,8 +41,8 @@ class RequirementsCoverageHTMLGenerator:
             documents_iterator=document_tree_iterator.iterator(),
             link_renderer=link_renderer,
             renderer=markup_renderer,
-            static_path="_static",
             document_type=DocumentType.deeptrace(),
+            strictdoc_version=__version__,
         )
 
         return output
