@@ -1,9 +1,10 @@
 from enum import Enum
+from typing import Optional
 
+from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
 from strictdoc.backend.sdoc.models.requirement import Requirement
 from strictdoc.backend.sdoc.models.section import FreeText, Section
-from strictdoc.backend.sdoc.models.type_system import ReferenceType
 from strictdoc.core.document_iterator import DocumentCachingIterator
 from strictdoc.core.traceability_index import TraceabilityIndex
 from strictdoc.export.rst.rst_templates import RSTTemplates
@@ -19,12 +20,17 @@ class RSTWriter:
     def __init__(self, index: TraceabilityIndex):
         self.index = index
 
-    def write(self, document, single_document):
+    def write(self, document: Document, single_document):
         document_iterator = DocumentCachingIterator(document)
         output = ""
 
         if not single_document:
-            output += self._print_rst_header(document.title, 0)
+            document_uid: Optional[str] = None
+            if document.config.uid is not None:
+                document_uid = document.config.uid
+            output += self._print_rst_header(
+                document.title, 0, reference_uid=document_uid
+            )
 
         for free_text in document.free_texts:
             output += self._print_free_text(free_text)
@@ -32,7 +38,9 @@ class RSTWriter:
         for content_node in document_iterator.all_content():
             if isinstance(content_node, Section):
                 output += self._print_rst_header(
-                    content_node.title, content_node.ng_level
+                    content_node.title,
+                    content_node.ng_level,
+                    content_node.reserved_uid,
                 )
                 for free_text in content_node.free_texts:
                     output += self._print_free_text(free_text)
@@ -40,6 +48,8 @@ class RSTWriter:
             elif isinstance(content_node, Requirement):
                 output += self._print_requirement_fields(content_node)
 
+        if output.endswith("\n\n"):
+            output = output[:-1]
         return output.lstrip()
 
     @staticmethod
@@ -64,7 +74,9 @@ class RSTWriter:
         return output
 
     @staticmethod
-    def _print_rst_header(string: str, level: int):
+    def _print_rst_header(
+        string: str, level: int, reference_uid: Optional[str]
+    ):
         assert isinstance(string, str), string
         assert isinstance(level, int), level
         chars = {
@@ -79,6 +91,13 @@ class RSTWriter:
         }
         header_char = chars[level]
         output = ""
+
+        # An RST reference looks like this:
+        # .. _SDOC-HIGH-VALIDATION:
+        if reference_uid is not None:
+            assert len(reference_uid) > 0, reference_uid
+            output += f".. _{reference_uid}:\n\n"
+
         output += string
         output += "\n"
         output += header_char.rjust(len(string), header_char)
@@ -96,67 +115,6 @@ class RSTWriter:
         )
         return output
 
-    def _print_requirement_fields_unused(self, section_content: Requirement):
-        output = ""
-        if section_content.uid is not None:
-            output += f".. _{section_content.uid}:"
-            output += "\n\n"
-
-        if section_content.title is not None:
-            output += self._print_rst_header(
-                section_content.title, section_content.ng_level
-            )
-
-        if section_content.uid is not None:
-            output += ".. list-table::\n"
-            output += "    :align: left\n"
-            output += "    :header-rows: 0\n\n"
-
-            output += "    * - **UID:**\n"
-            output += f"      - {section_content.uid}\n"
-            output += "\n"
-
-        if section_content.statement:
-            output += section_content.statement
-            output += "\n\n"
-        elif section_content.statement_multiline:
-            output += section_content.statement_multiline
-            output += "\n\n"
-        else:
-            pass  # raise RuntimeError('Statement is missing')
-
-        for comment in section_content.comments:
-            output += "**"
-            output += "Comment:"
-            output += "** "
-            output += comment.get_comment()
-            output += "\n\n"
-
-        requirement_parent_refs = section_content.get_requirement_references(
-            ReferenceType.PARENT
-        )
-        if len(requirement_parent_refs) > 0:
-            output += "**Parents:**"
-            output += "\n\n"
-            for reference in requirement_parent_refs:
-                output += f"- ``[{reference.ref_uid}]`` "
-                output += f":ref:`{reference.ref_uid}`"
-                output += "\n"
-            output += "\n"
-
-        if self.index.has_children_requirements(section_content):
-            output += "**Children:**"
-            output += "\n\n"
-            for child_requirement in self.index.get_children_requirements(
-                section_content
-            ):
-                output += f"- ``[{child_requirement.uid}]`` "
-                output += f":ref:`{child_requirement.uid}`"
-                output += "\n"
-            output += "\n"
-
-        return output
-
     def _print_free_text(self, free_text):
         assert isinstance(free_text, FreeText)
         if len(free_text.parts) == 0:
@@ -166,8 +124,7 @@ class RSTWriter:
             if isinstance(part, str):
                 output += part
             elif isinstance(part, InlineLink):
-                node = self.index.get_node_by_uid(part.link)
-                output += f"`{node.title}`_"
+                output += f":ref:`{part.link}`"
             else:
                 raise NotImplementedError
         output += "\n"
