@@ -1,11 +1,11 @@
 import argparse
 import os
 import sys
+from io import StringIO
+from xml.etree import ElementTree as etree
 
 import html5lib
 from tidylib import tidy_document
-from xml.etree import ElementTree as etree
-from io import StringIO
 
 parser = argparse.ArgumentParser(description="HTML Markup validator")
 parser.add_argument("input_file", type=str, help="Path to HTML file")
@@ -17,10 +17,10 @@ if not os.path.isfile(input_file):
     err = (
         f"error: html_markup_validator: input file does not exist: {input_file}"
     )
-    print(err)
+    print(err)  # noqa: T201
     exit(1)
 
-with open(input_file, "r", encoding="utf8") as file:
+with open(input_file, encoding="utf8") as file:
     html_content = file.read()
 
 errors = []
@@ -31,13 +31,33 @@ html5parser = html5lib.HTMLParser(strict=True)
 try:
     html5parser.parse(html_content)
 except Exception as e:
-    errors.append("Error: {}".format(str(e)))
+    errors.append(f"Error: {str(e)}")
 
 # Validation #2: tidylib
 _, tidylib_messages_string = tidy_document(
     html_content,
     options={
-        "new-blocklevel-tags": "main, aside, header, section, article, nav, svg, path, turbo-frame",  # noqa: E501
+        "new-blocklevel-tags": (
+            # HTML 5
+            "main, aside, header, footer, section, article, nav, menu, "
+            # Turbo.js
+            "turbo-frame, "
+            # SVG
+            "svg, path, line, circle, polyline, "
+            # StrictDoc
+            "sdoc-anchor, "
+            "sdoc-menu, sdoc-menu-handler, sdoc-menu-list, "
+            "sdoc-node, "
+            "sdoc-node-controls, "
+            "sdoc-requirement, "
+            "sdoc-requirement-uid, "
+            "sdoc-requirement-title, "
+            "sdoc-requirement-field, "
+            "sdoc-requirement-field-label, "
+            "sdoc-section, "
+            "sdoc-section-title, sdoc-section-text, "
+            "sdoc-main-placeholder, "
+        ),
         "char-encoding": "utf8",
         "input-encoding": "utf8",
         "output-encoding": "utf8",
@@ -56,14 +76,14 @@ for message in tidylib_messages_string.split("\n"):
 try:
     etree.parse(StringIO(html_content), etree.XMLParser())
 except Exception as e:
-    errors.append("Error: {}".format(str(e)))
+    errors.append(f"Error: {str(e)}")
 
 if len(errors) > 0 or len(warnings) > 0:
     for message in warnings + errors:
-        print(message)
+        print(message)  # noqa: T201
 
     if len(errors) > 0:
-        print(
+        print(  # noqa: T201
             "Validation COMPLETED: {} errors, {} warnings".format(
                 len(errors), len(warnings)
             )
@@ -71,11 +91,11 @@ if len(errors) > 0 or len(warnings) > 0:
         exit(1)
     else:
         # Warnings are ok for now.
-        print(
+        print(  # noqa: T201
             "Validation COMPLETED: {} errors, {} warnings".format(
                 len(errors), len(warnings)
             )
         )
         exit(0)
 else:
-    print("Validation COMPLETED: 0 errors, 0 warnings")
+    print("Validation COMPLETED: 0 errors, 0 warnings")  # noqa: T201
