@@ -5,18 +5,18 @@ import pytest
 from strictdoc.backend.sdoc.error_handling import StrictDocSemanticError
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.reference import (
+    BibReference,
     FileReference,
     ParentReqReference,
-    BibReference,
 )
 from strictdoc.backend.sdoc.models.requirement import (
-    Requirement,
     CompositeRequirement,
+    Requirement,
 )
 from strictdoc.backend.sdoc.models.section import Section
 from strictdoc.backend.sdoc.models.type_system import (
-    ReferenceType,
     BibEntryFormat,
+    ReferenceType,
 )
 from strictdoc.backend.sdoc.reader import SDReader
 from strictdoc.backend.sdoc.writer import SDWriter
@@ -346,7 +346,7 @@ This is a statement 3
     )
     requirement_1 = document.section_contents[0].section_contents[0]
     assert (
-        requirement_1.statement_multiline
+        requirement_1.reserved_statement
         == "This is a statement 1\nThis is a statement 2\nThis is a statement 3"
     )
 
@@ -421,7 +421,7 @@ This is a Rationale line 3
         document.section_contents[0].section_contents[0], Requirement
     )
     requirement_1 = document.section_contents[0].section_contents[0]
-    assert requirement_1.rationale_multiline == (
+    assert requirement_1.rationale == (
         "This is a Rationale line 1\n"
         "This is a Rationale line 2\n"
         "This is a Rationale line 3"
@@ -473,7 +473,7 @@ This is a child body part 3
     requirement_1 = document.section_contents[0].section_contents[0]
     assert requirement_1.ng_level == 2
     assert (
-        requirement_1.comments[0].comment_multiline
+        requirement_1.comments[0]
         == "This is a body part 1\nThis is a body part 2\nThis is a body part 3"
     )
 
@@ -526,7 +526,7 @@ body 1.1.1.1
     )
     requirement_1_1 = document.section_contents[0].section_contents[0]
     assert requirement_1_1.ng_level == 2
-    assert requirement_1_1.comments[0].comment_multiline == "body composite 1.1"
+    assert requirement_1_1.comments[0] == "body composite 1.1"
 
     assert isinstance(
         document.section_contents[0].section_contents[0].requirements[0],
@@ -536,10 +536,7 @@ body 1.1.1.1
         document.section_contents[0].section_contents[0].requirements[0]
     )
     assert requirement_1_1_1.ng_level == 3
-    assert (
-        requirement_1_1_1.comments[0].comment_multiline
-        == "body composite 1.1.1"
-    )
+    assert requirement_1_1_1.comments[0] == "body composite 1.1.1"
 
     assert isinstance(
         document.section_contents[0]
@@ -555,7 +552,7 @@ body 1.1.1.1
         .requirements[0]
     )
     assert requirement_1_1_1.ng_level == 4
-    assert requirement_1_1_1.comments[0].comment_multiline == "body 1.1.1.1"
+    assert requirement_1_1_1.comments[0] == "body 1.1.1.1"
 
 
 # This test is needed to make sure that the grammar details related
@@ -576,7 +573,7 @@ STATEMENT: 1
 
     document: Document = reader.read(sdoc_input)
     requirement = document.section_contents[0]
-    assert requirement.statement == "1"
+    assert requirement.reserved_statement == "1"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -604,10 +601,10 @@ REFS:
     references = requirement.references
     assert len(references) == 1
 
-    reference = references[0]
+    reference: FileReference = references[0]
     assert isinstance(reference, FileReference)
     assert reference.ref_type == ReferenceType.FILE
-    assert reference.file_entry.file_path == "/tmp/sample.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample.cpp"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -736,11 +733,11 @@ STATEMENT: ABC
 
     section = document.section_contents[0]
     assert isinstance(section, Section)
-    assert section.level == "123"
+    assert section.custom_level == "123"
 
     requirement = section.section_contents[0]
     assert isinstance(requirement, Requirement)
-    assert requirement.level == "456"
+    assert requirement.custom_level == "456"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -787,9 +784,9 @@ COMMENT: This requirement is very important
         document.section_contents[0].section_contents[0], Requirement
     )
     requirement_1 = document.section_contents[0].section_contents[0]
-    assert requirement_1.tags[0] == "Tag 1"
-    assert requirement_1.tags[1] == "Tag 2"
-    assert requirement_1.tags[2] == "Tag 3"
+    assert requirement_1.reserved_tags[0] == "Tag 1"
+    assert requirement_1.reserved_tags[1] == "Tag 2"
+    assert requirement_1.reserved_tags[2] == "Tag 3"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -901,12 +898,12 @@ STATEMENT: ABC
 
     document: Document = reader.read(sdoc_input)
     assert document.config.auto_levels is False
-    section = document.section_contents[0]
-    assert section.level == "123"
+    section: Section = document.section_contents[0]
+    assert section.custom_level == "123"
 
     requirement = section.section_contents[0]
     assert isinstance(requirement, Requirement)
-    assert requirement.level == "456"
+    assert requirement.custom_level == "456"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -1159,15 +1156,15 @@ REFS:
     assert reference.ref_type == ReferenceType.PARENT
     assert reference.ref_uid == "ID-001"
 
-    reference = references[1]
+    reference: FileReference = references[1]
     assert reference.ref_type == ReferenceType.FILE
     assert isinstance(reference, FileReference)
-    assert reference.file_entry.file_path == "/tmp/sample1.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample1.cpp"
 
     reference = references[2]
     assert reference.ref_type == ReferenceType.FILE
     assert isinstance(reference, FileReference)
-    assert reference.file_entry.file_path == "/tmp/sample2.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample2.cpp"
 
     reference = references[3]
     assert reference.ref_type == ReferenceType.BIB_REF
@@ -1211,10 +1208,10 @@ REFS:
     references = ll_requirement.references
     assert len(references) == 1
 
-    reference = references[0]
+    reference: FileReference = references[0]
     assert isinstance(reference, FileReference)
     assert reference.ref_type == ReferenceType.FILE
-    assert reference.file_entry.file_path == "/tmp/sample.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample.cpp"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -1254,20 +1251,20 @@ REFS:
     references = ll_requirement.references
     assert len(references) == 3
 
-    reference = references[0]
+    reference: FileReference = references[0]
     assert isinstance(reference, FileReference)
     assert reference.ref_type == ReferenceType.FILE
-    assert reference.file_entry.file_path == "/tmp/sample1.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample1.cpp"
 
     reference = references[1]
     assert isinstance(reference, FileReference)
     assert reference.ref_type == ReferenceType.FILE
-    assert reference.file_entry.file_path == "/tmp/sample2.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample2.cpp"
 
     reference = references[2]
     assert isinstance(reference, FileReference)
     assert reference.ref_type == ReferenceType.FILE
-    assert reference.file_entry.file_path == "/tmp/sample3.cpp"
+    assert reference.g_file_entry.g_file_path == "/tmp/sample3.cpp"
 
     writer = SDWriter()
     output = writer.write(document)
@@ -1674,3 +1671,49 @@ REFS:
         'Type item: ParentReqReference\\(.*ref_uid = "ID-001".*\\)',
         exc_info.value.args[0],
     )
+
+
+def test_210_uid_not_specified():
+    sdoc_input = """
+[DOCUMENT]
+TITLE: Test Doc
+
+[REQUIREMENT]
+""".lstrip()
+
+    reader = SDReader()
+
+    document: Document = reader.read(sdoc_input)
+    assert isinstance(document, Document)
+
+    requirement: Requirement = document.section_contents[0]
+    assert requirement.reserved_uid is None
+
+    writer = SDWriter()
+    output = writer.write(document)
+
+    assert sdoc_input == output
+
+
+# TODO: Does it make sense to disallow this case in the grammar?
+def test_211_present_but_empty():
+    sdoc_input = """
+[DOCUMENT]
+TITLE: Test Doc
+
+[REQUIREMENT]
+UID:
+""".lstrip()
+
+    reader = SDReader()
+
+    document: Document = reader.read(sdoc_input)
+    assert isinstance(document, Document)
+
+    requirement: Requirement = document.section_contents[0]
+    assert requirement.reserved_uid == ""
+
+    writer = SDWriter()
+    output = writer.write(document)
+
+    assert sdoc_input == output
